@@ -1,10 +1,13 @@
-from typing import Dict
+from typing import List, Dict
 import jsonschema
+import copy
 from linkml.utils.generator import Generator
 from linkml.generators.jsonschemagen import JsonSchemaGenerator
 from linkml_validator.models import SeverityEnum, ValidationMessage, ValidationResult
 from linkml_validator.plugins.base import BasePlugin
 from linkml_validator.utils import get_jsonschema, get_python_module, truncate
+from linkml_runtime.utils.schemaview import SchemaView
+from linkml_runtime.utils.formatutils import camelcase
 
 
 class JsonSchemaValidationPlugin(BasePlugin):
@@ -26,6 +29,45 @@ class JsonSchemaValidationPlugin(BasePlugin):
         self.python_module = get_python_module(schema)
         self.jsonschema_generator = jsonschema_generator
         self.generator_args = generator_args if generator_args else {}
+        self.jsonschema_obj_map = {}
+        class_list = None
+        if 'class_list' in kwargs:
+            class_list = kwargs['class_list']
+        self._generate_jsonschema(class_list=class_list)
+
+    def _generate_jsonschema(self, class_list: List[str] = None) -> None:
+        """
+        Generate JSON Schema representation for all (or specific) classes
+        in the schema.
+
+        Args:
+            class_list: A list of classes for which to generate JSONSchema
+
+        """
+        schemaview = SchemaView(self.schema)
+        jsonschema_obj = None
+        for class_name, class_def in schemaview.all_classes().items():
+            if not class_def.mixin:
+                formatted_name = camelcase(class_name)
+                if class_list:
+                    if formatted_name not in class_list:
+                        continue
+                if class_def.abstract:
+                    # Skip abstract classes
+                    continue
+                py_target_class = self.python_module.__dict__[formatted_name]
+                if formatted_name not in self.jsonschema_obj_map:
+                    if not jsonschema_obj:
+                        jsonschema_obj = get_jsonschema(
+                            schema=self.schema,
+                            py_target_class=py_target_class,
+                            generator=self.jsonschema_generator,
+                            **self.generator_args
+                        )
+                    target_jsonschema_obj = copy.deepcopy(jsonschema_obj)
+                    target_jsonschema_obj['properties'] = jsonschema_obj["$defs"][formatted_name].get('properties', {})
+                    target_jsonschema_obj['required'] = jsonschema_obj["$defs"][formatted_name].get('required', [])
+                    self.jsonschema_obj_map[formatted_name] = target_jsonschema_obj
 
     def process(self, obj: Dict, **kwargs) -> ValidationResult:
         """
@@ -47,13 +89,7 @@ class JsonSchemaValidationPlugin(BasePlugin):
             truncate_message = False
         target_class = kwargs["target_class"]
         valid = True
-        py_target_class = self.python_module.__dict__[target_class]
-        jsonschema_obj = get_jsonschema(
-            schema=self.schema,
-            py_target_class=py_target_class,
-            generator=self.jsonschema_generator,
-            **self.generator_args
-        )
+        jsonschema_obj = self.jsonschema_obj_map[target_class]
         validator = jsonschema.Draft7Validator(jsonschema_obj)
         errors = [x for x in validator.iter_errors(obj)]
         result = ValidationResult(
